## Summary

<!-- Brief description of what this PR does and why -->

## Changes

-

## Test Plan

- [ ] Tests added/updated
- [ ] All tests pass (`pytest`)
- [ ] Linting passes (`ruff check src/ tests/`)

## Related Issues

<!-- Link any related issues: Fixes #123, Closes #456 -->
